@@ -6,7 +6,7 @@ use strict;
 use Carp qw( croak );
 
 use vars qw($VERSION);
-$VERSION = '1.356'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.357'; # NOTE - Should be #.### (three decimal places)
 
 use POE::Resource::Clock qw( monotime time walltime sleep mono2wall wall2mono );
 
@@ -197,8 +197,8 @@ POE components are often just plain Perl objects.  The previously
 mentioned L<POE::Component::DirWatch::Object|POE::Component::DirWatch::Object> uses L<Moose|Moose>.  Other object
 and meta-object frameworks are compatible.
 
-Also of interest is L<POE::Component::Generic|POE::Component::Generic>, which is allows you to create
-a POE component from nearly nearly any blocking module.
+Also of interest is L<POE::Component::Generic|POE::Component::Generic>, which allows you to create
+a POE component from nearly any blocking module.
 
 There are quite a lot of components on the CPAN.  
 L<http://search.cpan.org/search?query=poe+component&mode=all>
